@@ -1,8 +1,9 @@
 package Math::Polynomial::Solve;
 
-require 5.008003;
+require 5.010001;
 
 use Math::Complex;
+use Math::Utils qw(:polynomial :utility);
 use Carp;
 use Exporter;
 use vars qw(@ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
@@ -12,8 +13,9 @@ use warnings;
 #
 # Three # for "I am here" messages, four # for variable dumps.
 # Five # for a dump of the companion matrix.
+# Six # for sturm structs (sign chain, etc).
 #
-#use Smart::Comments q(####);
+#use Smart::Comments q(######);
 
 @ISA = qw(Exporter);
 
@@ -38,6 +40,7 @@ use warnings;
 		poly_real_root_count
 		poly_sturm_chain
 		sturm_real_root_range_count
+		sturm_bisection
 		sturm_bisection_roots
 		sturm_sign_count
 		sturm_sign_chain
@@ -68,7 +71,7 @@ use warnings;
 	@{ $EXPORT_TAGS{'sturm'} },
 	@{ $EXPORT_TAGS{'utility'} } );
 
-our $VERSION = '2.67';
+our $VERSION = '2.71';
 
 #
 # Options to set or unset to force poly_roots() to use different
@@ -147,18 +150,6 @@ BEGIN
 #
 my $ascending_flag = 0;		# default 0, in a later version it will be 1.
 
-#
-# sign($x);
-#
-# Not exported.
-#
-sub sign
-{
-	return 1 if ($_[0] > 0);
-	return -1 if ($_[0] < 0);
-	return 0;
-}
-
 #
 # if (fltcmp($x, $y) == 0) { ... }
 #
@@ -173,9 +164,9 @@ sub fltcmp
 {
 	my($a, $b) = @_;
 
-	return -1 if ($a + $tolerance{fltcmp} < $b);
-	return 1 if ($a - $tolerance{fltcmp} > $b);
-	return 0;
+	return 0 if (abs($a - $b) <= $tolerance{fltcmp});
+	return -1 if ($a < $b);
+	return 1;
 }
 
 #
@@ -1263,15 +1254,11 @@ sub simplified_form
 #
 sub poly_derivative
 {
-	my @coefficients = ($ascending_flag)? reverse @_: @_;
-	my $degree = $#coefficients;
+	my @coefficients = ($ascending_flag)? @_: reverse @_;
 
-	return () if ($degree < 1);
+	my $d_ref = pl_derivative(\@coefficients);
 
-	$coefficients[$_] *= $degree-- for (0..$degree - 2);
-
-	pop @coefficients;
-	return ($ascending_flag)? reverse @coefficients: @coefficients;
+	return ($ascending_flag)? @{$d_ref}: reverse @{$d_ref};
 }
 
 #
@@ -1284,15 +1271,11 @@ sub poly_derivative
 #
 sub poly_antiderivative
 {
-	my @coefficients = ($ascending_flag)? reverse @_: @_;
-	my $degree = scalar @coefficients;
+	my @coefficients = ($ascending_flag)? @_: reverse @_;
 
-	return (0) if ($degree < 1);
+	my $d_ref = pl_antiderivative(\@coefficients);
 
-	$coefficients[$_] /= $degree-- for (0..$degree - 2);
-
-	push @coefficients, 0;
-	return ($ascending_flag)? reverse @coefficients: @coefficients;
+	return ($ascending_flag)? @{$d_ref}: reverse @{$d_ref};
 }
 
 #
@@ -1307,39 +1290,9 @@ sub poly_evaluate
 {
 	my($coef_ref, $xval_ref) = @_;
 
-	my @coefficients = ($ascending_flag)? reverse @$coef_ref: @$coef_ref;
-	my @values;
+	my @coefficients = ($ascending_flag)? @$coef_ref: reverse @$coef_ref;
 
-	#
-	# Allow some flexibility in sending the x-values.
-	#
-	if (ref $xval_ref eq "ARRAY")
-	{
-		@values = @$xval_ref;
-	}
-	else
-	{
-		#
-		# It could happen. Someone might type \$x instead of $x.
-		#
-		@values = ((ref $xval_ref eq "SCALAR")? $$xval_ref: $xval_ref);
-	}
-
-	#
-	# Move the leading coefficient off the polynomial list
-	# and use it as our starting value(s).
-	#
-	my @results = (shift @coefficients) x scalar @values;
-
-	foreach my $c (@coefficients)
-	{
-		foreach my $j (0..$#values)
-		{
-			$results[$j] = $results[$j] * $values[$j] + $c;
-		}
-	}
-
-	return wantarray? @results: $results[0];
+	return pl_evaluate(\@coefficients, $xval_ref);
 }
 
 #
@@ -1419,71 +1372,41 @@ sub poly_divide
 	my @numerator = @$n_ref;
 	my @divisor = @$d_ref;
 	my @quotient;
+	my @remainder;
 
 	my $temp_ascending_flag = $ascending_flag;
-	if ($ascending_flag)
+	unless ($ascending_flag)
 	{
 		@numerator = reverse @numerator;
 		@divisor = reverse @divisor;
-		$ascending_flag = 0;
+		$ascending_flag = 1;
 	}
 
 	#
 	# Just checking... removing any leading zeros.
 	#
-	shift @numerator while (@numerator and abs($numerator[0]) < $epsilon);
-	shift @divisor while (@divisor and abs($divisor[0]) < $epsilon);
+	pop @numerator while (@numerator and abs($numerator[$#numerator]) < $epsilon);
+	pop @divisor while (@divisor and abs($divisor[$#divisor]) < $epsilon);
 
-	my $n_degree = $#numerator;
-	my $d_degree = $#divisor;
-	my $q_degree = $n_degree - $d_degree;
+	my($quo_ref, $rem_ref) = pl_div(\@numerator, \@divisor);
 
-	return ([0], \@numerator) if ($q_degree < 0);
-	return (undef, undef) if ($d_degree < 0);
-
-	#
-	### poly_divide():
-	#### @numerator
-	#### by
-	#### @divisor
-	#
-	my $lead_coefficient = $divisor[0];
-
-	#
-	# Perform the synthetic division. The remainder will
-	# be what's left in the numerator.
-	#
-	for my $j (0..$q_degree)
-	{
-		#
-		# Get the next term for the quotient. We shift
-		# off the lead numerator term, which would become
-		# zero due to subtraction anyway.
-		#
-		my $q = (shift @numerator)/$lead_coefficient;
-
-		push @quotient, $q;
-
-		for my $k (1..$d_degree)
-		{
-			$numerator[$k - 1] -= $q * $divisor[$k];
-		}
-	}
+	@quotient = @{$quo_ref};
+	@remainder = @{$rem_ref};
 
 	#
 	# And once again, check for leading zeros in the remainder.
 	#
-	shift @numerator while (@numerator and abs($numerator[0]) < $epsilon);
-	push @numerator, 0 unless (@numerator);
+	pop @remainder while (@remainder and abs($remainder[$#remainder]) < $epsilon);
+	push @remainder, 0 unless (@remainder);
 
-	if ($temp_ascending_flag)
+	unless ($temp_ascending_flag)
 	{
-		@numerator = reverse @numerator;
+		@remainder = reverse @remainder;
 		@quotient = reverse @quotient;
 	}
 
 	$ascending_flag = $temp_ascending_flag;
-	return (\@quotient, \@numerator);
+	return (\@quotient, \@remainder);
 }
 
 #
@@ -1508,25 +1431,18 @@ sub poly_sturm_chain
 {
 	my @coefficients = @_;
 	my $degree = $#coefficients;
-	my @chain;
-	my($q, $r);
-	my $temp_ascending_flag = $ascending_flag;
+	my(@chain, @remd);
+	my($f1, $f2);
 
-	if ($ascending_flag)
-	{
-		$ascending_flag = 0;
-		@coefficients = reverse @coefficients;
-	}
+	@coefficients = reverse @coefficients unless ($ascending_flag);
 
-	my $f1 = [@coefficients];
-	my $f2 = [poly_derivative(@coefficients)];
+	$f1 = [@coefficients];
+	$f2 = pl_derivative(\@coefficients);
 
 	push @chain, $f1;
 
 	#
-	# NOTE:
-	# Go back to the 2.66 version of this block once
-	# the $ascending_flag check is obsolete.
+	# Start the first links of the chain.
 	#
 	SKIPIT: {
 		last SKIPIT if ($degree < 1); #return @chain if ($degree < 1);
@@ -1535,22 +1451,31 @@ sub poly_sturm_chain
 
 		last SKIPIT if ($degree < 2); #return @chain if ($degree < 2);
 
+		#
+		###### poly_sturm_chain chain before do loop:
+		###### @chain
+		#
 		do
 		{
-			($q, $r) = poly_divide($f1, $f2);
+			my ($q, $r) = pl_div($f1, $f2);
 			$f1 = $f2;
-			$f2 = [poly_constmult($r, -1)];
+
+			#
+			# Remove any leading zeros in the remainder.
+			#
+			@remd = @{$r};
+			pop @remd while (@remd and abs($remd[$#remd]) < $epsilon);
+
+			$f2 = (@remd)? [map {$_ * -1} @remd]: [0];
 			push @chain, $f2;
 		}
-		while ($#$r > 0);
-
+		while ($#remd > 0);
 	}
 
 	#
-	### poly_sturm_chain:
-	#### @chain
+	###### poly_sturm_chain:
+	###### @chain
 	#
-	$ascending_flag = $temp_ascending_flag;
 	return @chain;
 }
 
@@ -1566,25 +1491,11 @@ sub poly_sturm_chain
 sub poly_real_root_count
 {
 	my @coefficients = @_;
-	my $temp_ascending_flag = $ascending_flag;
-
-	if ($ascending_flag)
-	{
-		@coefficients = reverse @coefficients;
-		$ascending_flag = 0;
-	}
 
 	my @chain = poly_sturm_chain(@coefficients);
 
-	my $count = 
-		sturm_sign_count(sturm_sign_minus_inf(\@chain)) -
+	return sturm_sign_count(sturm_sign_minus_inf(\@chain)) -
 		sturm_sign_count(sturm_sign_plus_inf(\@chain));
-
-	$ascending_flag = $temp_ascending_flag;
-	return $count;
-
-	#return sturm_sign_count(sturm_sign_minus_inf(\@chain)) -
-	#	sturm_sign_count(sturm_sign_plus_inf(\@chain));
 }
 
 #
@@ -1602,7 +1513,117 @@ sub sturm_real_root_range_count
 
 	my @signs = sturm_sign_chain($chain_ref, [$x0, $x1]);
 
-	return sturm_sign_count(@{$signs[0]}) - sturm_sign_count(@{$signs[1]});
+	my $count0 = sturm_sign_count(@{$signs[0]});
+	my $count1 = sturm_sign_count(@{$signs[1]});
+
+	#
+	###### (from, to): join(", ", ($x0, $x1))
+	###### sign count from: $count0
+	###### sign count to: $count1
+	#
+	return $count0 - $count1;
+}
+
+#
+# @boundaries = sturm_bisection(\@chain, $from, $to);
+#
+# Using the bisection method on the root count method of Sturm, finds
+# the boundaries around the roots of a polynomial function.
+#
+# The elements of @boundaries will be two-element arrays bracketing
+# the root on the left and right.
+#
+# Will not bracket complex roots.
+#
+# In the :sturm export set.
+#
+sub sturm_bisection
+{
+	my($chain_ref, $from, $to) = @_;
+	my(@coefficients) = @{${$chain_ref}[0]};
+	my @boundaries;
+
+	#
+	#### @coefficients
+	#
+	#
+	# If we have a linear equation, just solve the thing. We're not
+	# going to find a useful second derivative, after all. (Which
+	# would raise the question of why we're here without a useful
+	# Sturm chain, but never mind...)
+	#
+	if ($#coefficients == 1)
+	{
+		my $root = linear_roots(@coefficients);
+
+		#
+		# But make sure the root is within the
+		# asked-for range.
+		#
+		return () if ($root < $from or $root > $to);
+		return ([$root, $root]);
+	}
+
+	#
+	# Do Sturm bisection here.
+	#
+	my $range_count = sturm_real_root_range_count($chain_ref, $from, $to);
+
+	#
+	# If we're down to one root in this range, use Laguerre's method
+	# to hunt it down.
+	#
+	return () if ($range_count == 0);
+	return ([$from, $to]) if ($range_count == 1);
+
+	#
+	# More than one root in this range, so subdivide
+	# until each root has its own range.
+	#
+	my $its = 0;
+
+	ROOT:
+	for (;;)
+	{
+		my $mid = ($to + $from)/2.0;
+		my $frommid_count = sturm_real_root_range_count($chain_ref, $from, $mid);
+		my $midto_count = sturm_real_root_range_count($chain_ref, $mid, $to);
+
+		#
+		#### $its
+		#### $from
+		#### $mid
+		#### $to
+		#### $frommid_count
+		#### $midto_count
+		#
+
+		#
+		# Bisect again if we only narrowed down to a range
+		# containing all the roots.
+		#
+		if ($frommid_count == 0)
+		{
+			$from = $mid;
+		}
+		elsif ($midto_count == 0)
+		{
+			$to = $mid;
+		}
+		else
+		{
+			#
+			# We've divided the roots between two ranges. Do it
+			# again until each range has a single root in it.
+			#
+			push @boundaries, sturm_bisection($chain_ref, $from, $mid);
+			push @boundaries, sturm_bisection($chain_ref, $mid, $to);
+			last ROOT;
+		}
+		croak "Too many iterations ($its) at mid=$mid\n" if ($its >= $iteration{sturm_bisection});
+		$its++;
+	}
+	return @boundaries;
 }
 
 #
@@ -1616,83 +1637,24 @@ sub sturm_real_root_range_count
 sub sturm_bisection_roots
 {
 	my($chain_ref, $from, $to) = @_;
-	my(@coefficients) = @{${$chain_ref}[0]};
+	my $cref0 = ${$chain_ref}[0];
+	my @boundaries = sturm_bisection($chain_ref, $from, $to);
 	my @roots;
 
+	my $temp_ascending_flag = $ascending_flag;
+	$ascending_flag = 1;
+
 	#
-	#### @coefficients
+	#### sturm_bisection() returns: @boundaries
 	#
-	#
-	# If we have a linear equation, just solve the thing. We're not
-	# going to find a useful second derivative, after all. (Which
-	# would raise the question of why we're here without a useful
-	# Sturm chain, but never mind...)
-	#
-	if ($#coefficients == 1)
+	for my $bracket (@boundaries)
 	{
-		push @roots, linear_roots(@coefficients);
-		return @roots;
+		my ($left, $right) = @$bracket;
+		push @roots, laguerre($cref0, ($left + $right)/2.0);
 	}
 
-	#
-	# Do Sturm bisection here.
-	#
-	my $range_count = sturm_real_root_range_count($chain_ref, $from, $to);
+	$ascending_flag = $temp_ascending_flag;
 
-	#
-	# If we're down to one root in this range, use Laguerre's method
-	# to hunt it down.
-	#
-	if ($range_count == 1)
-	{
-		push @roots, laguerre(\@coefficients, ($from + $to)/2.0);
-	}
-	elsif ($range_count > 1)
-	{
-		my $its = 0;
-
-		ROOT:
-		for (;;)
-		{
-			my $mid = ($to + $from)/2.0;
-			my $frommid_count = sturm_real_root_range_count($chain_ref, $from, $mid);
-			my $midto_count = sturm_real_root_range_count($chain_ref, $mid, $to);
-
-			#
-			#### $its
-			#### $from
-			#### $to
-			#### $mid
-			#### $frommid_count
-			#### $midto_count
-			#
-
-			#
-			# Bisect again if we only narrowed down to a range
-			# containing all the roots.
-			#
-			if ($frommid_count == 0)
-			{
-				$from = $mid;
-			}
-			elsif ($midto_count == 0)
-			{
-				$to = $mid;
-			}
-			else
-			{
-				#
-				# We've divided the roots between two ranges. Do it
-				# again until each range has a single root in it.
-				#
-				push @roots, sturm_bisection_roots($chain_ref, $from, $mid);
-				push @roots, sturm_bisection_roots($chain_ref, $mid, $to);
-				last ROOT;
-			}
-			croak "Too many iterations ($its) at mid=$mid\n" if ($its >= $iteration{sturm_bisection});
-			$its++;
-		}
-	}
 	return @roots;
 }
 
@@ -1711,10 +1673,10 @@ sub sturm_sign_minus_inf
 	foreach my $c (@$chain_ref)
 	{
 		my @coefficients = @$c;
-		push @signs, ((($#coefficients & 1) == 1)? -1: 1) * sign($coefficients[0]);
+		push @signs, ((($#coefficients & 1) == 1)? -1: 1) * sign($coefficients[$#coefficients]);
 	}
 
-	return @signs
+	return @signs;
 }
 
 #
@@ -1728,14 +1690,15 @@ sub sturm_sign_plus_inf
 {
 	my($chain_ref) = @_;
 	my @signs;
+	#my @signs = map{ sign(${$_}[0]) } @$chain_ref;
 
 	foreach my $c (@$chain_ref)
 	{
 		my @coefficients = @$c;
-		push @signs, sign($coefficients[0]);
+		push @signs, sign($coefficients[$#coefficients]);
 	}
 
-	return @signs
+	return @signs;
 }
 
 #
@@ -1752,21 +1715,12 @@ sub sturm_sign_chain
 	my $fn_count = $#$chain_ref;
 	my $x_count = $#$xvals_ref;
 	my @sign_chain;
-	my $col = 0;
-
-	#
-	# Temporarily force $ascending_flag to zero because
-	# the first row of the chain will have the the
-	# coefficients in that order.
-	#
-	my $temp_ascending_flag = $ascending_flag;
-	$ascending_flag = 0;
 
 	push @sign_chain, [] for (0..$x_count);
 
 	foreach my $p_ref (@$chain_ref)
 	{
-		my @ysigns = map($_ = sign($_), poly_evaluate($p_ref, $xvals_ref));
+		my @ysigns = sign(pl_evaluate($p_ref, $xvals_ref));
 
 		#
 		# We just retrieved the signs of a single function across
@@ -1789,11 +1743,12 @@ sub sturm_sign_chain
 		{
 			push @{$sign_chain[$j]}, shift @ysigns;
 		}
-
-		$col++;
 	}
 
-	$ascending_flag = $temp_ascending_flag;
+	#
+	###### sturm_sign_chain() returns
+	###### @sign_chain: @sign_chain
+	#
 	return @sign_chain;
 }
 
@@ -1834,13 +1789,7 @@ sub laguerre
 	my @xvalues;
 	my @roots;
 
-	my $temp_ascending_flag = $ascending_flag;
-
-	if ($ascending_flag)
-	{
-		$ascending_flag = 0;
-		$p_ref = [reverse @$p_ref];
-	}
+	$p_ref = [reverse @$p_ref] unless ($ascending_flag);
 
 	#
 	# Allow some flexibility in sending the x-values.
@@ -1860,9 +1809,9 @@ sub laguerre
 	foreach my $x (@xvalues)
 	{
 		#
-		### laguerre: looking near $x
-		### Coefficient: @$p_ref
-		### Degree: $n
+		#### laguerre looking near: $x
+		#### Coefficient: @$p_ref
+		#### Degree: $n
 		#
 		my $its = 0;
 
@@ -1873,7 +1822,7 @@ sub laguerre
 			# Get the values of the function and its first and
 			# second derivatives at X.
 			#
-			my($y, $dy, $d2y) = poly_derivaluate($p_ref, $x);
+			my($y, $dy, $d2y) = pl_dxevaluate($p_ref, $x);
 
 			if (abs($y) <= $tolerance{laguerre})
 			{
@@ -1883,7 +1832,7 @@ sub laguerre
 
 			#
 			#### At Iteration: $its
-			#### X: $x
+			#### x: $x
 			#### f(x): $y
 			#### f'(x): $dy
 			#### f''(x): $d2y
@@ -1894,9 +1843,9 @@ sub laguerre
 			$f = - $f if (abs($g - $f) > abs($g + $f));
 
 			#
-			#### g = $g
-			#### h = $h
-			#### f = $f
+			#### g: $g
+			#### h: $h
+			#### f: $f
 			#
 			# Divide by the largest value of $g plus
 			# $f, bearing in mind that $f is the result
@@ -1923,7 +1872,6 @@ sub laguerre
 		#### $x
 	}
 
-	$ascending_flag = $temp_ascending_flag;
 	return @roots;
 }
 
@@ -1942,13 +1890,7 @@ sub newtonraphson
 	my @xvalues;
 	my @roots;
 
-	my $temp_ascending_flag = $ascending_flag;
-
-	if ($ascending_flag)
-	{
-		$ascending_flag = 0;
-		$p_ref = [reverse @$p_ref];
-	}
+	$p_ref = [reverse @$p_ref] unless ($ascending_flag);
 
 	#
 	# Allow some flexibility in sending the x-values.
@@ -1977,10 +1919,10 @@ sub newtonraphson
 		for (;;)
 		{
 			#
-			# Get the values of the function and its first and
-			# second derivatives at X.
+			# Get the values of the function and its
+			# first derivative at X.
 			#
-			my($y, $dy, $d2y) = poly_derivaluate($p_ref, $x);
+			my($y, $dy, undef) = pl_dxevaluate($p_ref, $x);
 			my $dx = $y/$dy;
 			$x -= $dx;
 
@@ -1992,10 +1934,9 @@ sub newtonraphson
 
 			#
 			#### At Iteration: $its
-			#### X: $x
+			#### x: $x
 			#### f(x): $y
 			#### f'(x): $dy
-			#### f''(x): $d2y
 			#
 			croak "Too many iterations ($its) at dx=$dx\n" if ($its >= $iteration{newtonraphson});
 			$its++;
@@ -2005,15 +1946,9 @@ sub newtonraphson
 		#### $x
 	}
 
-	$ascending_flag = $temp_ascending_flag;
 	return @roots;
 }
 
-sub poly_gcd
-{
-	my($c1_ref, $c2_ref) = @_;
-}
-
 
 1;
 __END__
@@ -2070,6 +2005,7 @@ or
   my @x4 = quartic_roots($a, $b, $c, $d, $e);
 
 or
+
   use Math::Complex;  # The roots may be complex numbers.
   use Math::Polynomial;
   use Math::Polynomial::Solve qw(:classical ascending_order);
@@ -2124,6 +2060,57 @@ find the number of real roots present in a range of X values.
 In addition to the root-finding functions, the internal functions have
 also been exported for your use.
 
+=head2 DEPRECATED FUNCTIONS
+
+Many functions under the ':utility' tag are now duplicated in L<Math::Utils>.
+Consequently this module now uses Math::Utils itself, and will remove the
+redundant :utility functions by the next two releases.
+
+Note that the L<polynomial functions|Math::Utils/polynomial tag> 
+in Math::Utils all take the polynomial
+coefficients in ascending order, left to right.
+
+Scheduled to be removed are:
+
+=over 4
+
+=item fltcmp()
+
+Use Math::Utils's generate_fltcmp() or generate_relational() to
+create comparison functions with a built-in tolerance.
+
+=item poly_divide()
+
+Use Math::Utils's pl_div(). Note that unlike poly_divide(), checking for
+leading zeros isn't done by pl_div(), and is expected to be done by
+the caller.
+
+=item poly_evaluate()
+
+Use Math::Utils's pl_evaluate().
+
+=item poly_derivative()
+
+Use Math::Utils's pl_derivative().
+
+=item poly_antiderivative()
+
+Use Math::Utils's pl_antiderivative().
+
+=item poly_derivaluate()
+
+Use Math::Utils's pl_dxevaluate().
+
+=item poly_constmult()
+
+Not duplicated in Math::Utils, use L<Math::VecStat>'s vecprod().
+
+=item simplified_form()
+
+This function is simply going to be dropped.
+
+=back
+
 =head2 EXPORTED BY DEFAULT
 
 =head3 ascending_order()
@@ -2173,7 +2160,7 @@ would have been written instead as
 The function is a temporary measure to help with the change in the API when
 version 3.00 of this module is released. At that point coefficients will be
 in ascending order by default, and you will need to use C<ascending_order(0)>
-to use the old (current) style, although you will get a deprecation warning.
+to use the old (current) style.
 
 =head2 Numeric Functions
 
@@ -2386,11 +2373,26 @@ This is equivalent to:
   my @signs = sturm_sign_chain(\@chain, [$x0, $x1]);
   $no_unique_roots = sturm_sign_count(@{$signs[0]}) - sturm_sign_count(@{$signs[1]});
 
+=head3 sturm_bisection()
+
+Finds the boundaries around the roots of a polynomial function,
+using the root count method of Sturm.
+
+ @boundaries = sturm_bisection(\@chain, $from, $to);
+
+The elements of @boundaries will be a list of two-element arrays, each
+element bracketing a root.
+
+It will not bracket complex roots.
+
+This allows you to use a different root-finding function than laguerre(),
+which is the default function used by sturm_bisection_roots().
+
 =head3 sturm_bisection_roots()
 
-Return the I<real> roots counted by L</sturm_real_root_range_count()>. Uses the
-bisection method combined with C<sturm_real_root_range_count()> to narrow the range
-to a single root, then uses L</laguerre()> to find its value.
+Return the I<real> roots counted by L</sturm_real_root_range_count()>.
+Uses L</sturm_bisection()> to bracket the roots of the polynomial,
+then uses L</laguerre()> to close in on each root.
 
   my($from, $to) = (-1000, 0);
   my @chain = poly_sturm_chain(@coefficients);
@@ -2480,6 +2482,11 @@ These are internal functions used by the other functions listed above
 that may also be useful to the user, or which affect the behavior of
 other functions. They are all exported under the tag "utility".
 
+Because many of these functions are useful outside the area of polynomials,
+they have been taken, with changes, to the module L<Math::Utils>, and
+have been deprecated for this module. See L</DEPRECATED FUNCTIONS>
+for more information, and the descriptions below for details.
+
 =head3 epsilon()
 
 Returns the machine epsilon value that was calculated when this module was
@@ -2496,6 +2503,9 @@ more information on the subject.
 
 =head3 fltcmp()
 
+The function is DEPRECATED. See L<Math::Utils> and the section "compare tag"
+for a replacement.
+
 Compare two floating point numbers within a degree of accuracy.
 
 Like most functions ending in "cmp", this one returns -1 if the first
@@ -2645,6 +2655,9 @@ A comparison function that determines if one argument is less than, equal to,
 or greater than, the other. Comparisons are made within a range determined by
 the tolerance.
 
+Since this function is L<deprecated|/DEPRECATED FUNCTIONS>, its tolerance
+will also be removed when the function is remvoed.
+
 =back
 
 =head3 poly_derivative()
@@ -2656,6 +2669,10 @@ Leading zeros are removed before returning the derivative, so the length
 of the returned polynomial may be even shorter than expected from the length of the original
 polynomial. Returns an empty list if the polynomial is a simple constant.
 
+This function is L<deprecated|/DEPRECATED FUNCTIONS>, and will be
+removed in two releases. Use the module L<Math::Utils> and the tag
+:polynomial for a replacement.
+
 =head3 poly_antiderivative()
 
 Returns the coefficients of the antiderivative of the polynomial. The
@@ -2664,12 +2681,19 @@ constant term is set to zero; to override this use
   @integral = poly_antiderivative(@coefficients);
   $integral[$#integral] = $const_term;
 
+This function is L<deprecated|/DEPRECATED FUNCTIONS>, and will be
+removed in two releases. Use the module L<Math::Utils> and the tag
+:polynomial for a replacement.
+
 =head3 simplified_form()
 
 Return the polynomial adjusted by removing any leading zero coefficients
 and placing it in a monic polynomial form (all coefficients divided by the
 coefficient of the highest power).
 
+This function is L<deprecated|/DEPRECATED FUNCTIONS>, and will be
+removed in two releases.
+
 =head3 poly_evaluate()
 
 Returns the values of the polynomial given a list of arguments. Unlike
@@ -2695,9 +2719,14 @@ or return a scalar.
   my $x_median = ($xvals[0] + $xvals[$#xvals])/2.0;
   my $y_median = poly_evaluate(\@coefficients, $x_median);
 
+This function is L<deprecated|/DEPRECATED FUNCTIONS>, and will be
+removed in two releases. Use the module L<Math::Utils> under the section
+"polynomial tag" for a replacement.
 
 =head3 poly_derivaluate();
 
+This is one of the L<deprecated functions|/DEPRECATED FUNCTIONS>
+
 Given an X value, returns the y-values of the polynomial, its first derivative,
 and its second derivative.
 
@@ -2710,6 +2739,10 @@ If the polynomial is a linear equation, the second derivative value will be
 zero.  Similarly, if the "equation" is a constant, the first derivative value
 will be zero.
 
+This function is L<deprecated|/DEPRECATED FUNCTIONS>, and will be
+removed in two releases. Use the module L<Math::Utils> under the section
+"polynomial tag" for a replacement.
+
 =head3 poly_nonzero_term_count()
 
 Returns a simple count of the number of coefficients that aren't zero.
@@ -2722,6 +2755,9 @@ C<poly_evaluate()>, uses the reference of the coefficient list.
   my @coefficients = (1, 7, 0, 12, 19);
   my @coef3 = poly_constmult(\@coefficients, 3);
 
+This function is L<deprecated|/DEPRECATED FUNCTIONS>, and will be
+removed in two releases. Use the module L<Math::VecStat> for a replacement.
+
 =head3 poly_divide()
 
 Divide one polynomial by another. Like C<poly_evaluate()>, the function takes
@@ -2734,11 +2770,13 @@ and a remainder.
   my @quotient = @$q;
   my @remainder = @$r;
 
+This function is L<deprecated|/DEPRECATED FUNCTIONS>, and will be
+removed in two releases. Use the module L<Math::Utils> under the section
+"polynomial tag" for a replacement.
+
 =head1 EXPORT
 
-Currently there is one default export, L<ascending_order|ascending_order()>,
-although this function will be deprecated after version 3.00 of this module
-is released.
+Currently there is one default export, L<ascending_order|ascending_order()>.
 
 The remaining functions may be individually named in an export list,
 but there are also four export tags:
